<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../forms/aboutdialog.ui" line="14"/>
        <source>About Qmmp</source>
        <translation>Acerca de Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="49"/>
        <source>About</source>
        <translation>Acerca</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="63"/>
        <source>Authors</source>
        <translation>Autores</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="77"/>
        <source>Translators</source>
        <translation>Tradutores</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="91"/>
        <source>Thanks To</source>
        <translation>Agradecimentos</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="105"/>
        <source>License Agreement</source>
        <translation>Contrato de licenciamento</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="71"/>
        <source>Qt-based Multimedia Player (Qmmp)</source>
        <translation>Qt-based Multimedia Player (Qmmp)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="75"/>
        <source>Version: %1</source>
        <translation>Versão: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="76"/>
        <source>Using Qt %1 (compiled with Qt %2)</source>
        <translation>Utiliza Qt %1 (compilado com Qt %2)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="79"/>
        <source>(c) %1-%2 Qmmp Development Team</source>
        <translation>(c) %1-%2 Equipa de desenvolvimento do Qmmp</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="84"/>
        <source>Transports:</source>
        <translation>Transportes:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="94"/>
        <source>Decoders:</source>
        <translation>Descodificadores:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="106"/>
        <source>Engines:</source>
        <translation>Mecanismos:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="117"/>
        <source>Effects:</source>
        <translation>Efeitos:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="162"/>
        <source>File dialogs:</source>
        <translation>Diálogos de ficheiro:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="175"/>
        <source>User interfaces:</source>
        <translation>Interface de utilizador:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="150"/>
        <source>Output plugins:</source>
        <translation>Suplementos de saída:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="129"/>
        <source>Visual plugins:</source>
        <translation>Suplementos visuais:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="140"/>
        <source>General plugins:</source>
        <translation>Suplementos genéricos:</translation>
    </message>
</context>
<context>
    <name>AddUrlDialog</name>
    <message>
        <location filename="../forms/addurldialog.ui" line="14"/>
        <source>Enter URL to add</source>
        <translation>Introduza o URL a adicionar</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="46"/>
        <source>&amp;Add</source>
        <translation>&amp;Adicionar</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="53"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <location filename="../addurldialog.cpp" line="88"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>ColumnEditor</name>
    <message>
        <location filename="../forms/columneditor.ui" line="14"/>
        <source>Edit Column</source>
        <translation>Editar coluna</translation>
    </message>
    <message>
        <location filename="../forms/columneditor.ui" line="36"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location filename="../forms/columneditor.ui" line="76"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <location filename="../forms/columneditor.ui" line="64"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/columneditor.ui" line="29"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="85"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="86"/>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="90"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="93"/>
        <source>Genre</source>
        <translation>Género</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="94"/>
        <source>Comment</source>
        <translation>Comentário</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="95"/>
        <source>Composer</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="96"/>
        <source>Duration</source>
        <translation>Duração</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="101"/>
        <source>Year</source>
        <translation>Ano</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="100"/>
        <source>Track Index</source>
        <translation>Índice da faixa</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="87"/>
        <source>Artist - Album</source>
        <translation>Artista - Álbum</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="88"/>
        <source>Artist - Title</source>
        <translation>Artista - Título</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="89"/>
        <source>Album Artist</source>
        <translation>Artista do álbum</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="91"/>
        <source>Track Number</source>
        <translation>Número da faixa</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="92"/>
        <source>Two-digit Track Number</source>
        <translation>Número da faixa com 2 dígitos</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="97"/>
        <source>Disc Number</source>
        <translation>Número do disco</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="98"/>
        <source>File Name</source>
        <translation>Nome do ficheiro</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="99"/>
        <source>File Path</source>
        <translation>Caminho do ficheiro</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="102"/>
        <source>Parent Directory Name</source>
        <translation>Nome do diretório superior</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="103"/>
        <source>Parent Directory Path</source>
        <translation>Caminho do diretório superior</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="104"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../forms/configdialog.ui" line="14"/>
        <source>Qmmp Settings</source>
        <translation>Definições do Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="58"/>
        <source>Playlist</source>
        <translation>Lista de reprodução</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="67"/>
        <source>Plugins</source>
        <translation>Suplementos</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="76"/>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="85"/>
        <source>Connectivity</source>
        <translation>Conectividade</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="94"/>
        <location filename="../forms/configdialog.ui" line="854"/>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="123"/>
        <source>Metadata</source>
        <translation>Meta-dados</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="143"/>
        <source>Convert %20 to blanks</source>
        <translation>Converter %20 para espaços vazios</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="129"/>
        <source>Load metadata from files</source>
        <translation>Carregar meta-dados dos ficheiros</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="136"/>
        <source>Convert underscores to blanks</source>
        <translation>Converter &quot;underscores&quot; para espaços vazios</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="150"/>
        <source>Group format:</source>
        <translation>Formato de grupo:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="160"/>
        <location filename="../forms/configdialog.ui" line="583"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="170"/>
        <source>Read tags while loading a playlist</source>
        <translation>Ler etiquetas ao carregar a lista de reprodução</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="180"/>
        <source>Directory Scanning Options</source>
        <translation>Opções de análise de diretórios</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="186"/>
        <source>Restrict files to:</source>
        <translation>Restringir ficheiros a:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="196"/>
        <location filename="../forms/configdialog.ui" line="461"/>
        <source>Exclude files:</source>
        <translation>Ficheiros excluidos:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="209"/>
        <source>Miscellaneous</source>
        <translation>Diversos</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="215"/>
        <source>Auto-save playlist when modified</source>
        <translation>Guardar lista de reprodução ao modificar</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="222"/>
        <source>Clear previous playlist when opening new one</source>
        <translation>Limpar lista de reprodução ao abrir uma nova</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="229"/>
        <source>Skip already existing tracks</source>
        <translation>Ignorar faixas existentes</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="277"/>
        <location filename="../configdialog.cpp" line="334"/>
        <source>Preferences</source>
        <translation>Preferências</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="290"/>
        <location filename="../configdialog.cpp" line="337"/>
        <source>Information</source>
        <translation>Informações</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="332"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="337"/>
        <source>Filename</source>
        <translation>Nome do ficheiro</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="349"/>
        <source>Look and Feel</source>
        <translation>Aspeto e comportamento</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="355"/>
        <source>Language:</source>
        <translation>Idioma:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="388"/>
        <source>Display average bitrate</source>
        <translation>Mostrar taxa de dados média</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="398"/>
        <source>Playback</source>
        <translation>Reprodução</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="404"/>
        <source>Continue playback on startup</source>
        <translation>Retomar reprodução ao iniciar</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="411"/>
        <source>Determine file type by content</source>
        <translation>Determinar tipo de ficheiro por conteúdo</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="418"/>
        <source>Add files from command line to this playlist:</source>
        <translation>Adicionar ficheiros da linha de comandos para a lista de reprodução:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="435"/>
        <source>Cover Image Retrieve</source>
        <translation>Obtenção de capa de álbum</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="441"/>
        <source>Use separate image files</source>
        <translation>Utilizar ficheiros de imagens distintos</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="451"/>
        <source>Include files:</source>
        <translation>Ficheiros incluídos:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="473"/>
        <source>Recursive search depth:</source>
        <translation>Nível de procura recursiva:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="505"/>
        <source>URL Dialog</source>
        <translation>Diálogo de URL</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="511"/>
        <source>Auto-paste URL from clipboard</source>
        <translation>Colar URL existente na área de transferência</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="521"/>
        <source>CUE Editor</source>
        <translation>Editor de ficheiros CUE</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="527"/>
        <source>Use system font</source>
        <translation>Utilizar tipo de letra do sistema</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="548"/>
        <source>Font:</source>
        <translation>Tipo de letra:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="573"/>
        <source>???</source>
        <translation>???</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="612"/>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="624"/>
        <source>Enable proxy usage</source>
        <translation>Ativar utilização de proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="631"/>
        <source>Proxy type:</source>
        <translation>Tipo de proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="641"/>
        <source>Proxy host name:</source>
        <translation>Nome do servidor proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="654"/>
        <source>Proxy port:</source>
        <translation>Porta do proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="667"/>
        <source>Use authentication with proxy</source>
        <translation>Utilizar autenticação de proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="674"/>
        <source>Proxy user name:</source>
        <translation>Nome de utilizador:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="687"/>
        <source>Proxy password:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="724"/>
        <source>Replay Gain</source>
        <translation>Replay Gain</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="730"/>
        <source>Replay Gain mode:</source>
        <translation>Modo Replay Gain:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="747"/>
        <source>Preamp:</source>
        <translation>Amplificador:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="779"/>
        <location filename="../forms/configdialog.ui" line="824"/>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="792"/>
        <source>Default gain:</source>
        <translation>Ganho padrão:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="844"/>
        <source>Use  peak info to prevent clipping</source>
        <translation>Utilizar picos para impedir distorção</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="860"/>
        <source>Buffer size:</source>
        <translation>Memória:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="886"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="919"/>
        <source>Use software volume control</source>
        <translation>Utilizar controlo de volume da aplicação</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="959"/>
        <source>Use two passes for equalizer</source>
        <translation>Usar duas passagens para o equalizador</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="902"/>
        <source>Volume adjustment step:</source>
        <translation>Valor para ajuste de volume:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="926"/>
        <source>Output bit depth:</source>
        <translation>Profundidade de saída:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="867"/>
        <source>Use dithering</source>
        <translation>Utilizar &apos;dithering&apos;</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="66"/>
        <source>Track</source>
        <translation>Faixa</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="67"/>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="68"/>
        <source>Disabled</source>
        <translation>Inativo</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="75"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="76"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="89"/>
        <source>File Types</source>
        <translation>Tipos de ficheiro</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="206"/>
        <source>Transports</source>
        <translation>Transporte</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="217"/>
        <source>Decoders</source>
        <translation>Descodificadores</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="228"/>
        <source>Engines</source>
        <translation>Mecanismos</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="240"/>
        <source>Effects</source>
        <translation>Efeitos</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="251"/>
        <source>Visualization</source>
        <translation>Visualização</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="263"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="274"/>
        <source>Output</source>
        <translation>Saída</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="285"/>
        <source>File Dialogs</source>
        <translation>Diálogos de ficheiro</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="297"/>
        <source>User Interfaces</source>
        <translation>Interface de utilizador</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="347"/>
        <source>&lt;Autodetect&gt;</source>
        <translation>&lt;Deteção automática&gt;</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="348"/>
        <source>Brazilian Portuguese</source>
        <translation>Português do Brasil</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="349"/>
        <source>Chinese Simplified</source>
        <translation>Mandarim simplificado</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="350"/>
        <source>Chinese Traditional</source>
        <translation>Mandarim tradicional</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="351"/>
        <source>Czech</source>
        <translation>Checo</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="352"/>
        <source>Dutch</source>
        <translation>Holândes</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="353"/>
        <source>English</source>
        <translation>Inglês</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="354"/>
        <source>French</source>
        <translation>Francês</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="355"/>
        <source>Galician</source>
        <translation>Galiciano</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="356"/>
        <source>German</source>
        <translation>Alemão</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="357"/>
        <source>Greek</source>
        <translation>Grego</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="358"/>
        <source>Hebrew</source>
        <translation>Hebraico</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="359"/>
        <source>Hungarian</source>
        <translation>Húngaro</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="360"/>
        <source>Indonesian</source>
        <translation>Indonésio</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="361"/>
        <source>Italian</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="362"/>
        <source>Japanese</source>
        <translation>Japonês</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="363"/>
        <source>Kazakh</source>
        <translation>Cazaque</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="364"/>
        <source>Korean</source>
        <translation>Coreano</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="365"/>
        <source>Lithuanian</source>
        <translation>Lituano</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="366"/>
        <source>Polish</source>
        <translation>Polaco</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="367"/>
        <source>Portuguese</source>
        <translation>Português</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="368"/>
        <source>Russian</source>
        <translation>Russo</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="369"/>
        <source>Serbian</source>
        <translation>Sérvio</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="370"/>
        <source>Slovak</source>
        <translation>Eslovaco</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="371"/>
        <source>Swedish</source>
        <translation>Sueco</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="372"/>
        <source>Spanish</source>
        <translation>Espanhol</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="373"/>
        <source>Turkish</source>
        <translation>Turco</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="374"/>
        <source>Ukrainian</source>
        <translation>Ucraniano</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="375"/>
        <source>Serbian (Ijekavian)</source>
        <translation>Sérvio (Ijekavian)</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="376"/>
        <source>Serbian (Ekavian)</source>
        <translation>Sérvio (Ekavian)</translation>
    </message>
</context>
<context>
    <name>CoverEditor</name>
    <message>
        <location filename="../forms/covereditor.ui" line="22"/>
        <source>Image source:</source>
        <translation>Origem da imagem:</translation>
    </message>
    <message>
        <location filename="../forms/covereditor.ui" line="76"/>
        <source>Load</source>
        <translation>Carregar</translation>
    </message>
    <message>
        <location filename="../forms/covereditor.ui" line="83"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../forms/covereditor.ui" line="90"/>
        <source>Save as...</source>
        <translation>Guardar como...</translation>
    </message>
    <message>
        <location filename="../covereditor.cpp" line="33"/>
        <source>External file</source>
        <translation>Ficheiro externo</translation>
    </message>
    <message>
        <location filename="../covereditor.cpp" line="34"/>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
</context>
<context>
    <name>CoverViewer</name>
    <message>
        <location filename="../coverviewer.cpp" line="35"/>
        <source>&amp;Save As...</source>
        <translation>&amp;Guardar como...</translation>
    </message>
    <message>
        <location filename="../coverviewer.cpp" line="68"/>
        <source>Save Cover As</source>
        <translation>Guardar capa como</translation>
    </message>
    <message>
        <location filename="../coverviewer.cpp" line="70"/>
        <location filename="../coverviewer.cpp" line="83"/>
        <source>Images</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <location filename="../coverviewer.cpp" line="81"/>
        <source>Open Image</source>
        <translation>Abrir imagem</translation>
    </message>
</context>
<context>
    <name>CueEditor</name>
    <message>
        <location filename="../forms/cueeditor.ui" line="40"/>
        <source>Load</source>
        <translation>Carregar</translation>
    </message>
    <message>
        <location filename="../forms/cueeditor.ui" line="47"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../forms/cueeditor.ui" line="54"/>
        <source>Save as...</source>
        <translation>Guardar como...</translation>
    </message>
    <message>
        <location filename="../cueeditor.cpp" line="131"/>
        <source>Open CUE File</source>
        <translation>Abrir ficheiro CUE</translation>
    </message>
    <message>
        <location filename="../cueeditor.cpp" line="133"/>
        <location filename="../cueeditor.cpp" line="152"/>
        <source>CUE Files</source>
        <translation>Ficheiros CUE</translation>
    </message>
    <message>
        <location filename="../cueeditor.cpp" line="150"/>
        <source>Save CUE File</source>
        <translation>Guardar ficheiro CUE</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../forms/detailsdialog.ui" line="14"/>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="44"/>
        <source>Open the directory containing this file</source>
        <translation>Abrir o diretório que contém este ficheiro</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="47"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="63"/>
        <source>Summary</source>
        <translation>Resumo</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="206"/>
        <source>%1/%2</source>
        <translation>%1/%2</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="258"/>
        <source>Cover</source>
        <translation>Capa de álbum</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="284"/>
        <source>Lyrics</source>
        <translation>Letra das faixas</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="304"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="305"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="306"/>
        <source>Album artist</source>
        <translation>Artista do álbum</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="307"/>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="308"/>
        <source>Comment</source>
        <translation>Comentário</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="309"/>
        <source>Genre</source>
        <translation>Género</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="310"/>
        <source>Composer</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="311"/>
        <source>Year</source>
        <translation>Ano</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="312"/>
        <source>Track</source>
        <translation>Faixa</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="313"/>
        <source>Disc number</source>
        <translation>Número do disco</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="331"/>
        <source>Duration</source>
        <translation>Duração</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="334"/>
        <source>Bitrate</source>
        <translation>Taxa de dados</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="334"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="335"/>
        <source>Sample rate</source>
        <translation>Frequência</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="335"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="336"/>
        <source>Channels</source>
        <translation>Canais</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="337"/>
        <source>Sample size</source>
        <translation>Tamanho da amostra</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="337"/>
        <source>bits</source>
        <translation>bits</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="338"/>
        <source>Format name</source>
        <translation>Nome do formato</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="339"/>
        <source>File size</source>
        <translation>Tamanho do ficheiro</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="339"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="383"/>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="383"/>
        <source>No</source>
        <translation>Não</translation>
    </message>
</context>
<context>
    <name>JumpToTrackDialog</name>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="14"/>
        <source>Jump To Track</source>
        <translation>Ira para a faixa</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="46"/>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="85"/>
        <location filename="../jumptotrackdialog.cpp" line="122"/>
        <location filename="../jumptotrackdialog.cpp" line="153"/>
        <source>Queue</source>
        <translation>Fila</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="104"/>
        <source>Jump To</source>
        <translation>Ir para</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="98"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="99"/>
        <source>J</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="120"/>
        <location filename="../jumptotrackdialog.cpp" line="151"/>
        <source>Unqueue</source>
        <translation>Retirar da fila</translation>
    </message>
</context>
<context>
    <name>MetaDataFormatterMenu</name>
    <message>
        <location filename="../metadataformattermenu.cpp" line="26"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="27"/>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="28"/>
        <source>Album Artist</source>
        <translation>Artista do álbum</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="31"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="32"/>
        <source>Track Number</source>
        <translation>Número da faixa</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="33"/>
        <source>Two-digit Track Number</source>
        <translation>Número da faixa com 2 dígitos</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="37"/>
        <source>Track Index</source>
        <translation>Índice da faixa</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="39"/>
        <source>Genre</source>
        <translation>Género</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="40"/>
        <source>Comment</source>
        <translation>Comentário</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="41"/>
        <source>Composer</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="46"/>
        <source>Duration</source>
        <translation>Duração</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="57"/>
        <source>Parent Directory Path</source>
        <translation>Caminho do diretório superior</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="59"/>
        <source>Bitrate</source>
        <translation>Taxa de dados</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="60"/>
        <source>Sample Rate</source>
        <translation>Frequência</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="61"/>
        <source>Number of Channels</source>
        <translation>Número de canais</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="62"/>
        <source>Sample Size</source>
        <translation>Tamanho da amostra</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="63"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="64"/>
        <source>Decoder</source>
        <translation>Descodificador</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="67"/>
        <source>File Size</source>
        <translation>Tamanho do ficheiro</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="42"/>
        <source>Disc Number</source>
        <translation>Número do disco</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="47"/>
        <source>File Name</source>
        <translation>Nome do ficheiro</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="48"/>
        <source>File Path</source>
        <translation>Caminho do ficheiro</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="43"/>
        <source>Year</source>
        <translation>Ano</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="50"/>
        <source>Condition</source>
        <translation>Condição</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="49"/>
        <source>Artist - Title</source>
        <translation>Artista - Título</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="54"/>
        <source>Artist - [Year] Album</source>
        <translation>Artista - [Ano] Álbum</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="56"/>
        <source>Parent Directory Name</source>
        <translation>Nome do diretório superior</translation>
    </message>
</context>
<context>
    <name>PlayListDownloader</name>
    <message>
        <location filename="../playlistdownloader.cpp" line="123"/>
        <source>Unsupported playlist format</source>
        <translation>Formato de lista não suportado</translation>
    </message>
</context>
<context>
    <name>PlayListHeaderModel</name>
    <message>
        <location filename="../playlistheadermodel.cpp" line="35"/>
        <source>Artist - Title</source>
        <translation>Artista - Título</translation>
    </message>
    <message>
        <location filename="../playlistheadermodel.cpp" line="185"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../playlistheadermodel.cpp" line="186"/>
        <source>Add Column</source>
        <translation>Adicionar coluna</translation>
    </message>
</context>
<context>
    <name>PlayListManager</name>
    <message>
        <location filename="../playlistmanager.cpp" line="181"/>
        <location filename="../playlistmanager.cpp" line="327"/>
        <source>Playlist</source>
        <translation>Lista de reprodução</translation>
    </message>
</context>
<context>
    <name>PlayListTrack</name>
    <message>
        <location filename="../playlisttrack.cpp" line="245"/>
        <source>Streams</source>
        <translation>Emissões</translation>
    </message>
    <message>
        <location filename="../playlisttrack.cpp" line="250"/>
        <source>Empty group</source>
        <translation>Grupo vazio</translation>
    </message>
</context>
<context>
    <name>QmmpUiSettings</name>
    <message>
        <location filename="../qmmpuisettings.cpp" line="59"/>
        <source>Playlist</source>
        <translation>Lista de reprodução</translation>
    </message>
</context>
<context>
    <name>QtFileDialogFactory</name>
    <message>
        <location filename="../qtfiledialog.cpp" line="35"/>
        <source>Qt File Dialog</source>
        <translation>Diálogo de ficheiro Qt</translation>
    </message>
</context>
<context>
    <name>TagEditor</name>
    <message>
        <location filename="../forms/tageditor.ui" line="14"/>
        <source>Tag Editor</source>
        <translation>Editor de etiquetas</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="38"/>
        <source>Title:</source>
        <translation>Título:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="64"/>
        <source>Artist:</source>
        <translation>Artista:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="90"/>
        <source>Album:</source>
        <translation>Álbum:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="113"/>
        <source>Album artist:</source>
        <translation>Artista do álbum:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="123"/>
        <source>Composer:</source>
        <translation>Compositor:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="143"/>
        <source>Genre:</source>
        <translation>Género:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="169"/>
        <source>Track:</source>
        <translation>Faixa:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="190"/>
        <location filename="../forms/tageditor.ui" line="228"/>
        <location filename="../forms/tageditor.ui" line="260"/>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="203"/>
        <source>Year:</source>
        <translation>Ano:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="250"/>
        <source>Disc number:</source>
        <translation>Número do disco:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="275"/>
        <source>Comment:</source>
        <translation>Comentário:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="311"/>
        <source>Include selected tag in file</source>
        <translation>Incluir etiqueta escolhida no ficheiro</translation>
    </message>
</context>
<context>
    <name>TemplateEditor</name>
    <message>
        <location filename="../forms/templateeditor.ui" line="14"/>
        <source>Template Editor</source>
        <translation>Editor de modelos</translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="39"/>
        <source>Reset</source>
        <translation>Restaurar</translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="46"/>
        <source>Insert</source>
        <translation>Inserir</translation>
    </message>
</context>
<context>
    <name>UiHelper</name>
    <message>
        <location filename="../uihelper.cpp" line="138"/>
        <location filename="../uihelper.cpp" line="150"/>
        <source>All Supported Bitstreams</source>
        <translation>Todas as emissões suportadas</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="144"/>
        <source>Select one or more files to open</source>
        <translation>Selecione um ou mais ficheiros a abrir</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="156"/>
        <source>Select one or more files to play</source>
        <translation>Selecione um ou mais ficheiros a reproduzir</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="164"/>
        <source>Choose a directory</source>
        <translation>Selecione um diretório</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="180"/>
        <location filename="../uihelper.cpp" line="206"/>
        <source>Playlist Files</source>
        <translation>Ficheiros de lista de reprodução</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="182"/>
        <source>Open Playlist</source>
        <translation>Abrir lista de reprodução</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="209"/>
        <location filename="../uihelper.cpp" line="228"/>
        <source>Save Playlist</source>
        <translation>Guardar lista de reprodução</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="228"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 já existe.
Gostaria de o substituir?</translation>
    </message>
</context>
<context>
    <name>WinFileAssocPage</name>
    <message>
        <location filename="../forms/winfileassocpage.ui" line="17"/>
        <source>Media files handled by Qmmp:</source>
        <translation>Ficheiros geridos pelo Qmmp:</translation>
    </message>
    <message>
        <location filename="../forms/winfileassocpage.ui" line="49"/>
        <source>Select All</source>
        <translation>Marcar todos</translation>
    </message>
    <message>
        <location filename="../winfileassocpage.cpp" line="109"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../winfileassocpage.cpp" line="110"/>
        <source>Not all files could be associated. Please check your security permissions and retry.</source>
        <translation>Nem todos os tipos de ficheiro foram associados. Verifique as suas permissões e tente novamente.</translation>
    </message>
    <message>
        <location filename="../winfileassocpage.cpp" line="117"/>
        <source>Check all file types in the list</source>
        <translation>Marcar todos os tipos de ficheiro da lista</translation>
    </message>
    <message>
        <location filename="../winfileassocpage.cpp" line="118"/>
        <source>Check the media file extensions you would like Qmmp to handle. When you click Apply, the checked files will be associated with Qmmp. If you uncheck a media type, the file association will be restored.</source>
        <translation>Assinale as extensões de ficheiros que pretende gerir com o Qmmp. Se clicar em Aplicar, os tipos de ficheiro marcados serão associados. Se desmarcar um tipo, a associação original será restaurada.</translation>
    </message>
    <message>
        <location filename="../winfileassocpage.cpp" line="122"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Restoration doesn&apos;t work on Windows Vista/7.</source>
        <translation>&lt;b&gt;Nota:&lt;/b&gt; o restauro não funciona nos sistemas Windows Vista/7.</translation>
    </message>
</context>
</TS>
